<?php

//if accessed directly exit
if(!defined('ABSPATH')) exit;

class MediclinicMikadoSkin extends MediclinicMikadoSkinAbstract {
    /**
     * Skin constructor. Hooks to mediclinic_mikado_admin_scripts_init and mediclinic_mikado_enqueue_admin_styles
     */
    public function __construct() {
        $this->skinName = 'mikado';

        //hook to
        add_action('mediclinic_mikado_admin_scripts_init', array($this, 'registerStyles'));
        add_action('mediclinic_mikado_admin_scripts_init', array($this, 'registerScripts'));

        add_action('mediclinic_mikado_enqueue_admin_styles', array($this, 'enqueueStyles'));
        add_action('mediclinic_mikado_enqueue_admin_scripts', array($this, 'enqueueScripts'));

        add_action('mediclinic_mikado_enqueue_meta_box_styles', array($this, 'enqueueStyles'));
        add_action('mediclinic_mikado_enqueue_meta_box_scripts', array($this, 'enqueueScripts'));

		add_action( 'admin_enqueue_scripts', array( $this, 'setShortcodeJSParams' ), 5 ); // 5 is set to be same permission as Gutenberg plugin have

		$this->setIcons();
		$this->setMenuItemPosition();
    }

    /**
     * Method that registers skin scripts
     */
    public function registerScripts() {
        $this->scripts['bootstrap.min'] = 'assets/js/bootstrap.min.js';
        $this->scripts['jquery.nouislider.min'] = 'assets/js/mkdf-ui/jquery.nouislider.min.js';
        $this->scripts['mkdf-ui-admin'] = 'assets/js/mkdf-ui/mkdf-ui.js';
        $this->scripts['mkdf-bootstrap-select'] = 'assets/js/mkdf-ui/mkdf-bootstrap-select.min.js';
        $this->scripts['mkdf-select2-script'] = 'assets/js/mkdf-ui/select2.js';

        foreach ($this->scripts as $scriptHandle => $scriptPath) {
            mediclinic_mikado_register_skin_script($scriptHandle, $scriptPath);
        }
    }

    /**
     * Method that registers skin styles
     */
    public function registerStyles() {
        $this->styles['mkdf-bootstrap'] = 'assets/css/mkdf-bootstrap.css';
        $this->styles['mkdf-page-admin'] = 'assets/css/mkdf-page.css';
        $this->styles['mkdf-options-admin'] = 'assets/css/mkdf-options.css';
        $this->styles['mkdf-meta-boxes-admin'] = 'assets/css/mkdf-meta-boxes.css';
        $this->styles['mkdf-ui-admin'] = 'assets/css/mkdf-ui/mkdf-ui.css';
        $this->styles['mkdf-forms-admin'] = 'assets/css/mkdf-forms.css';
        $this->styles['mkdf-import'] = 'assets/css/mkdf-import.css';
        $this->styles['font-awesome-admin'] = 'assets/css/font-awesome/css/font-awesome.min.css';
        $this->styles['mkdf-select2-style'] = 'assets/css/select2.css';

        foreach ($this->styles as $styleHandle => $stylePath) {
            mediclinic_mikado_register_skin_style($styleHandle, $stylePath);
        }
    }

	/**
	 * Method that set menu icons
	 */
	public function setIcons() {
		$this->icons = array(
			'slider' => $this->getSkinURI().'/assets/img/admin-logo-icon.png',
            'slider-lite' => $this->getSkinURI().'/assets/img/admin-logo-icon.png',
			'carousel' => $this->getSkinURI().'/assets/img/admin-logo-icon.png',
			'testimonial' => $this->getSkinURI().'/assets/img/admin-logo-icon.png',
			'portfolio' => $this->getSkinURI().'/assets/img/admin-logo-icon.png',
			'team' => $this->getSkinURI().'/assets/img/admin-logo-icon.png',
			'masonry-gallery' => $this->getSkinURI().'/assets/img/admin-logo-icon.png',
			'proofing-gallery' => $this->getSkinURI().'/assets/img/admin-logo-icon.png',
            'course' => $this->getSkinURI().'/assets/img/admin-logo-icon.png',
            'lesson' => $this->getSkinURI().'/assets/img/admin-logo-icon.png',
            'quiz' => $this->getSkinURI().'/assets/img/admin-logo-icon.png',
            'question' => $this->getSkinURI().'/assets/img/admin-logo-icon.png',
			'options' => $this->getSkinURI().'/assets/img/admin-logo-icon.png'
		);
	}

	/**
	 * Method that set menu item position
	 */
	public function setMenuItemPosition() {
		$this->itemPosition = array(
			'carousel' => 4,
			'testimonial' => 4,
			'portfolio' => 4,
			'team' => 4,
			'masonry-gallery' => 4,
			'proofing-gallery' => 4,
            'course' => 20,
            'lesson' => 21,
            'question' => 22,
            'quiz' => 23,
			'options' => 4
		);
	}

    /**
     * Method that renders options page
     *
     * @see MediclinicMikadoSkin::getHeader()
     * @see MediclinicMikadoSkin::getPageNav()
     * @see MediclinicMikadoSkin::getPageContent()
     */
    public function renderOptions() {
        global $mediclinic_mikado_Framework;
        $tab    		= mediclinic_mikado_get_admin_tab();
        $active_page 	= $mediclinic_mikado_Framework->mkdOptions->getAdminPageFromSlug($tab);
        $current_theme 	= wp_get_theme();

        if ($active_page == null) return;
        ?>
        <div class="mkdf-options-page mkdf-page">
            <?php $this->getHeader($current_theme->get('Name'), $current_theme->get('Version')); ?>
            <div class="mkdf-page-content-wrapper">
                <div class="mkdf-page-content">
                    <div class="mkdf-page-navigation mkdf-tabs-wrapper vertical left clearfix">
                        <?php $this->getPageNav($tab); ?>
                        <?php $this->getPageContent($active_page, $tab); ?>
                    </div>
                </div>
            </div>
        </div>
        <a id='back_to_top' href='#'>
            <span class="fa-stack">
                <span class="fa fa-angle-up"></span>
            </span>
        </a>
    <?php }

    /**
     * Method that renders header of options page.
     * @param string theme name to display
     * @param string theme version to display
     * @param bool whether to show save button or not
     *
     * @see MediclinicMikadoSkinAbstract::loadTemplatePart()
     */
    public function getHeader($themeName = '', $themeVersion, $showSaveButton = true) {
        $this->loadTemplatePart('header', array(
            'themeName' => $themeName,
            'themeVersion' => $themeVersion,
            'showSaveButton' => $showSaveButton)
        );
    }

    /**
     * Method that loads page navigation
     * @param string $tab current tab
     * @param bool $isImportPage if is import page highlighted that tab
     *
     * @see MediclinicMikadoSkinAbstract::loadTemplatePart()
     */
    public function getPageNav($tab, $isImportPage = false, $isBackupOptionsPage = false) {
        $this->loadTemplatePart('navigation', array(
            'tab' => $tab,
            'isImportPage' => $isImportPage,
            'isBackupOptionsPage' => $isBackupOptionsPage
        ));
    }

    /**
     * Method that loads current page content
     *
     * @param MediclinicMikadoAdminPage $page current page to load
     * @param string $tab current page slug
     * @param bool $showAnchors whether to show anchors template or not
     *
     * @see MediclinicMikadoSkinAbstract::loadTemplatePart()
     */
    public function getPageContent($page, $tab, $showAnchors = true) {
        $this->loadTemplatePart('content', array(
            'page' => $page,
            'tab' => $tab,
            'showAnchors' => $showAnchors
        ));
    }

    /**
     * Method that loads content for import page
     */
    public function getImportContent() {
        $this->loadTemplatePart('content-import');
    }

	/**
     * Method that loads content for import page
     */
    public function getBackupOptionsContent() {
        $this->loadTemplatePart('backup-options');
    }

    /**
     * Method that loads anchors and save button template part
     *
	 * @param MediclinicMikadoAdminPage $page current page to load
     *
     * @see MediclinicMikadoSkinAbstract::loadTemplatePart()
     */
    public function getAnchors($page) {
        $this->loadTemplatePart('anchors', array('page' => $page));
    }

	/**
	 * Method that renders backup options page
	 *
	 * @see MediclinicMikadoSkin::getHeader()
	 * * @see MediclinicMikadoSkin::getPageNav()
	 * * @see MediclinicMikadoSkin::getImportContent()
	 */
	public function renderBackupOptions() { ?>
		<div class="mkdf-options-page mkdf-page">
			<?php $this->getHeader(mediclinic_mikado_get_theme_info_item('Name'), mediclinic_mikado_get_theme_info_item('Version'), false); ?>
			<div class="mkdf-page-content-wrapper">
				<div class="mkdf-page-content">
					<div class="mkdf-page-navigation mkdf-tabs-wrapper vertical left clearfix">
						<?php $this->getPageNav('backup_options', false, true); ?>
						<?php $this->getBackupOptionsContent(); ?>
					</div>
				</div>
			</div>
		</div>
	<?php }
	
    /**
     * Method that renders import page
     *
     * @see MediclinicMikadoSkin::getHeader()
     * * @see MediclinicMikadoSkin::getPageNav()
     * * @see MediclinicMikadoSkin::getImportContent()
     */
    public function renderImport() { ?>
        <div class="mkdf-options-page mkdf-page">
            <?php $this->getHeader(mediclinic_mikado_get_theme_info_item('Name'), mediclinic_mikado_get_theme_info_item('Version'), false); ?>
            <div class="mkdf-page-content-wrapper">
                <div class="mkdf-page-content">
                    <div class="mkdf-page-navigation mkdf-tabs-wrapper vertical left clearfix">
                        <?php $this->getPageNav('tabimport', true); ?>
                        <?php $this->getImportContent(); ?>
                    </div>
                </div>
            </div>
        </div>
    <?php }
}
?>